;;; Directory Local Variables
;;; See Info node `(emacs) Directory Variables' for more information.

((python-mode
  (py-continuation-offset . 4)
  (py-smart-indentation)
  (py-indent-offset . 2)
  (flycheck-pylintrc . "pylintrc")))



