/* CSS for CRM excel import page */

table.excel-import {
  tbody {
    border-top: solid 1px black;
    border-bottom: solid 1px black;
  }

  .item-row {
    td {
      vertical-align: middle;
    }

    td, & + tr td {
      border-top: solid 1px black;
    }
  }
}
